<template>
    <div class="notice">
        <el-dialog
            v-model="dialogVisible"
            :title="title"
            width="60%"
        >
          <el-form :model="queryParams" :inline="true" label-width="90px">
            <el-form-item label="专业类别">
              <el-radio-group v-model="queryParams.expertType">
                <el-radio-button label="">全部</el-radio-button>
                <el-radio-button label="1">安全评价</el-radio-button>
                <el-radio-button label="2">检验检测</el-radio-button>
              </el-radio-group>
            </el-form-item>
            <el-form-item label="姓名">
              <el-input
                  v-model="queryParams.name"
                  placeholder="姓名"
                  style="width: 250px"
              />
            </el-form-item>
            <el-form-item label="手机号">
              <el-input
                  v-model="queryParams.phone"
                  placeholder="手机号"
                  style="width: 250px"
              />
            </el-form-item>
            <el-form-item label="评价师等级">
              <el-select v-model="queryParams.level" style="width: 250px" placeholder="评价师等级" >
                <el-option
                    v-for="item in levelList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.name"
                />
              </el-select>
            </el-form-item>
            <el-form-item label="专业方向">
              <el-select v-model="queryParams.major" value-key="id" style="width: 250px" placeholder="专业方向">
                <el-option
                    v-for="item in majorList"
                    :key="item.id"
                    :label="item.label"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
            <el-form-item label="专业方向">
              <el-select v-model="queryParams.post" style="width: 250px" placeholder="请选择职务">
                <el-option
                    v-for="item in postList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.name"
                />
              </el-select>
            </el-form-item>
            <el-form-item>
              <el-button type="primary" icon="Search" @click="search">搜索</el-button>
              <el-button icon="Refresh" @click="research">重置</el-button>
            </el-form-item>
          </el-form>
          <el-table v-loading="loading" ref="tableRef" :data="dataList" :border="true" @select="select" @selection-change="handleSelectionChange">
            <el-table-column type="selection" width="55" />
            <el-table-column label="用户ID" prop="id" align="center"  />
            <el-table-column label="姓名" prop="name" align="center" width="110" />
            <el-table-column label="手机号" prop="phone" align="center" width="125" />
            <el-table-column label="用户名" prop="username" align="center" width="110" />
            <el-table-column label="性别" prop="sex" align="center" >
              <template #default="scope">
                <span v-if="scope.row.sex === 0">男</span>
                <span v-if="scope.row.sex === 1">女</span>
              </template>
            </el-table-column>
            <el-table-column label="所属机构" prop="agency.name" align="center" width="110"  />
            <el-table-column label="社保" prop="socialSecurity" align="center" width="120">
              <template #default="scope">
                <div class="demo-image__preview" v-if="scope.row.socialAttach && scope.row.socialAttach.length>0">
                  <el-image
                      style="width: 100px; height: 100px"
                      :src= "scope.row.socialAttach[0]"
                      :zoom-rate="1.2"
                      :max-scale="7"
                      :min-scale="0.2"
                      :preview-src-list="scope.row.socialAttach"
                      :initial-index="0"
                      fit="cover"
                      :preview-teleported= true
                  />
                </div>
              </template>
            </el-table-column>
            <el-table-column label="医保" prop="medicalInsurance" align="center" width="120">
              <template #default="scope">
                <div class="demo-image__preview" v-if="scope.row.medicalAttach && scope.row.medicalAttach.length>0">
                  <el-image
                      style="width: 100px; height: 100px"
                      :src="scope.row.medicalAttach[0]"
                      :zoom-rate="1.2"
                      :max-scale="7"
                      :min-scale="0.2"
                      :preview-src-list="scope.row.medicalAttach"
                      :initial-index="0"
                      fit="cover"
                      :preview-teleported= true
                  />
                </div>
              </template>
            </el-table-column>
            <el-table-column label="工资清单" prop="salaryList" align="center" width="120">
              <template #default="scope">
                <div class="demo-image__preview" v-if="scope.row.salaryAttach && scope.row.salaryAttach.length>0">
                  <el-image
                      style="width: 100px; height: 100px"
                      :src= "scope.row.salaryAttach[0]"
                      :zoom-rate="1.2"
                      :max-scale="7"
                      :min-scale="0.2"
                      :preview-src-list="scope.row.salaryAttach"
                      :initial-index="0"
                      fit="cover"
                      :preview-teleported= true
                  />
                </div>
              </template>
            </el-table-column>
            <el-table-column label="职务" prop="post" align="center" width="120" />
            <el-table-column label="职称" prop="jobTitle" align="center"  />
            <el-table-column label="专业方向" prop="majorNames" align="center" width="100" />
            <el-table-column label="评价师等级" prop="level" align="center" width="100" />
            <el-table-column label="业绩汇总" prop="summary" align="center"  />
            <el-table-column label="最近评价时间" prop="lastTime" align="center" width="120" />
          </el-table>

          <pagination
              v-show="total > 0"
              :total="total"
              v-model:page="queryParams.pageNum"
              v-model:limit="queryParams.pageSize"
              @pagination="getList"
          />
            <template #footer>
                    <span class="dialog-footer">
                        <el-button @click="dialogVisible = false" size="default">取 消</el-button>
                        <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
                    </span>
            </template>
        </el-dialog>
    </div>
</template>
<script setup>
import {getCurrentInstance, onMounted, reactive, ref, toRefs,defineEmits} from "vue";
import {getDictList} from "@/api/backManage/evaluate";
import {ElMessage, ElMessageBox} from "element-plus";
import Cookies from "js-cookie";
import {delMonitor, getExpertList, getMonitorList} from "@/api/sysUsers";
const { proxy } = getCurrentInstance();
const loading = ref(false);
const emit = defineEmits(['getName'])
const data = reactive({
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    expertType: "",
    name: '',
    phone: '',
    level: '',
    major: null,
    post: ''
  },
  total: 0,
  dataList: [],
  majorList: [],
  levelList: [
    {
      id: '1',
      name: '一级'
    },
    {
      id: '2',
      name: '二级'
    },
    {
      id: '3',
      name: '三级'
    },
    {
      id: '4',
      name: '其他'
    },
  ],
  postList: [
    {
      id: '1',
      name: '法人'
    },
    {
      id: '2',
      name: '过程控制负责人'
    },
    {
      id: '3',
      name: '机构负责人'
    },
    {
      id: '4',
      name: '技术负责人'
    },
    {
      id: '5',
      name: '员工'
    },
  ],
  dialogVisible: false,
  title: '',
  selected: []
})
const tableRef = ref()
const { queryParams, total, dataList, majorList, levelList, postList, dialogVisible,title,selected } = toRefs(data);

const openDialog = (type) => {
  getMajor()
  research()
  data.selected = []
  data.title = type
  data.dialogVisible = true
}

const onSubmit = async () => {
  if(data.selected.length>0)
  emit('getName',data.title,data.selected[data.selected.length - 1])
  data.dialogVisible = false
}

const getList = async () => {
  loading.value = true
  const res = await getExpertList(data.queryParams)
  if(res.code == 200){
    data.dataList = res.data.list.map(item => {
      return{
        ...item,
        socialAttach: item.socialAttach.map(s => { return import.meta.env.VITE_APP_BASE_API + '/' + s.path}),
        medicalAttach: item.medicalAttach.map(s => { return import.meta.env.VITE_APP_BASE_API + '/' + s.path}),
        salaryAttach: item.salaryAttach.map(s => { return import.meta.env.VITE_APP_BASE_API + '/' + s.path})
      }
    })
    console.log('RES',data.dataList)
    data.total = res.data.total
  }else{
    ElMessage.warning(res.message)
  }
  loading.value = false
}

const getMajor = async () => {
  const queryParams = {
    pageNum: 1,
    pageSize: 50,
    dictType: 'sys_major_orientation'
  }
  const res = await getDictList(queryParams);
  if(res.code === 200){
    data.majorList = res.data.list
  }else{
    ElMessage.warning(res.message)
  }
}

const select = ((selection, row) => {
  tableRef.value.clearSelection()
  if(selection.length == 0)  {
    return
  }
  tableRef.value.toggleRowSelection(row, true);
})

const handleSelectionChange = (val) => {
  data.selected = val
}

const search = ()=>{
  data.queryParams.pageNum = 1
  getList()
}

const research = ()=>{
  data.queryParams = {
    pageNum: 1,
    pageSize: 10,
    expertType: "",
    name: '',
    phone: '',
    level: '',
    major: null,
    post: ''
  }
  getList()
}

defineExpose({
    openDialog
});

</script>

<style scoped lang="scss">
.notice{
    :deep(.el-form .el-form-item__label) {
        font-size: 15px;
    }

    ::v-deep(.el-table th.el-table__cell:nth-child(1) .cell) {
      visibility: hidden;
    }

    .file {
        display: flex;
        flex-direction: column;
        align-items: flex-start;
    }
}
</style>
